==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/assist/material/vo/MaterialContractPaymentVO.java <==
package com.ejianc.business.assist.material.vo;

import com.ejianc.business.contractpub.util.ConvertField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 辅料中心采购合同-付款阶段
 *
 * @author generator
 */
public class MaterialContractPaymentVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ConvertField(targetField = "sourceId,id")
    private Long id;
    @ConvertField
    private Integer dr;
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    @ConvertField(targetField = "paymentNodeName")
    private String paymentName; // 付款阶段名称
    @ConvertField(targetField = "totalActualPayRecTax")
    private BigDecimal paymentScale; // 付款阶段比例(%)
    private String memo; // 备注

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public String getPaymentName() {
        return paymentName;
    }

    public void setPaymentName(String paymentName) {
        this.paymentName = paymentName;
    }

    public BigDecimal getPaymentScale() {
        return paymentScale;
    }

    public void setPaymentScale(BigDecimal paymentScale) {
        this.paymentScale = paymentScale;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-assistrmat-api-3.0.0-20231011.015035-399-sources.jar: com/ejianc/business/assist/material/vo/MaterialContractPaymentVO.java <==
package com.ejianc.business.assist.material.vo;

import com.ejianc.business.contractpub.util.ConvertField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 辅料中心采购合同-付款阶段
 *
 * @author generator
 */
public class MaterialContractPaymentVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ConvertField(targetField = "sourceId,id")
    private Long id;
    @ConvertField
    private Integer dr;
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    @ConvertField(targetField = "paymentNodeName")
    private String paymentName; // 付款阶段名称
    @ConvertField(targetField = "totalActualPayRecTax")
    private BigDecimal paymentScale; // 付款阶段比例(%)
    private String memo; // 备注
    //模板导出使用
    private String paymentScaleStr;

    public String getPaymentScaleStr() {
        return paymentScaleStr;
    }

    public void setPaymentScaleStr(String paymentScaleStr) {
        this.paymentScaleStr = paymentScaleStr;
    }

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public String getPaymentName() {
        return paymentName;
    }

    public void setPaymentName(String paymentName) {
        this.paymentName = paymentName;
    }

    public BigDecimal getPaymentScale() {
        return paymentScale;
    }

    public void setPaymentScale(BigDecimal paymentScale) {
        this.paymentScale = paymentScale;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
